#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-BDavpg4lNkT4e69WNc0QVL
key:                  stack-2.9.3.1-BDavpg4lNkT4e69WNc0QVL
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  ad85f250df4f2e7ede2e442f1f40386d
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-BDavpg4lNkT4e69WNc0QVL
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-GWc1LmCE0o9Bpe9MYCbSNj
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-FMAjddYCnoo35p0Ajg6Jk8 array-0.5.6.0
    async-2.2.6-1mBgL12wSAHIlTk64oC4Cy
    attoparsec-0.14.4-BlWH2qVtwe5IKN4IgjppV5 base-4.18.2.1
    base64-bytestring-1.2.1.0-8gB06GrihcB6Sq9DkPfsbE
    bytestring-0.11.5.3 casa-client-0.0.4-3zZS9Lb71u1HvtEFsqAO3S
    casa-types-0.0.3-1xUlv8giMsO8NDsABxC9jx
    colour-2.3.7-52DaKKnDbdRf7CUEo3dC5
    conduit-1.3.6.1-4sdnvTzdBma5YgRtH9r4P9
    conduit-extra-1.3.8-JsZlK7bbP5W8Y5cbrIEDfl containers-0.6.7
    crypton-1.0.4-4tCArmqzb3m53iwYBOQdXY
    crypton-conduit-0.2.3-Bes73DPfOq5Cv73YbS8xxR deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-H2QjO0vfy7Y45ns0T18nV
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.9-JQkwHpbholZIa3smKixdXr filepath-1.4.300.1
    fsnotify-0.4.4.0-D60FfUGeNeN4kBZBUrgDyj
    generic-deriving-1.14.7-EdpMS6VUjSWAYwhkxCiLC8
    hackage-security-0.6.3.2-EteSo2rCEyfBgZK8Gq7yPv
    hashable-1.4.7.0-FDr33SOXd6ZL3RCqzuvond
    hi-file-parser-0.1.8.0-CfnZLVkCVTvBxleInZtAsB
    hpack-0.38.0-KOmM34DQAsaE0LmCeIS5dK hpc-0.6.2.0
    http-client-0.7.19-CdoyGBdmx4CJG3r6obV7W1
    http-client-tls-0.3.6.4-AnHGLSahOg9HVl4h6a2CCE
    http-conduit-2.3.9.1-IhIEGxcJ0jxNTiAgdkscf
    http-download-0.2.1.0-C4tfoLmnSrL1CHmLsXsoza
    http-types-0.12.4-7VF1fWYoZaw5btElYXN8F2
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-CUR26vqFQfiC1od3cj1V0b mtl-2.3.1
    mustache-2.4.3.1-I9UUxhmpTQx7Xp7Be6xD1W
    neat-interpolation-0.5.1.4-LFOt5AO0D0nGk9QG0dEalI
    network-uri-2.6.4.2-GaZ2e74kZTJHR0YFZY0APg
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-1ZOUgEBAg4Z36ZcICQWhpn
    pantry-0.8.3-EF7APpOHwSFJ4CQly64cGD
    path-0.9.6-1wADnfQAZA99zoAP25QpzT
    path-io-1.8.2-JDcPEuOdkzSBrE8uogAd7a
    persistent-2.14.6.0-KQ5ms5DpPkNLF00rBKfpso
    persistent-sqlite-2.13.2.0-I0cJy0dYei53o6PDgwnYK2 pretty-1.1.3.6
    primitive-0.9.1.0-4hlhnHtP0gACqmGq3bJZxL process-1.6.19.0
    project-template-0.2.1.0-BvptItP7PS49XaU4CG8ze9
    random-1.2.1.3-J8W47WuTchP2SADTtbNvax
    retry-0.9.3.1-15d8BjIrFPK8NYaTwqck1E
    rio-0.1.24.0-JBW6BaHiyub4m2SBTmJfNr
    rio-prettyprint-0.1.8.0-Dz1o41B5IBnB46DkvbtCI0
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl stm-2.5.1.0
    streaming-commons-0.2.3.1-D7OAgZ9RRPTJsLXm4XqJ5p
    tar-0.6.0.0-3TLQi4mx0aTEG3FHqZMPsa template-haskell-2.20.0.0
    temporary-1.3-2H1UQnxEoYo405QWjo3iMT text-2.0.2
    text-metrics-0.3.3-3TWDwrwAO4D6rSKlVj0EfL
    th-reify-many-0.1.10-4rsDUPMq6zW2mIIg4DT14r time-1.12.2
    tls-2.0.6-LTAjvKPnAMkKcDqlHiGgeW transformers-0.6.1.0
    typed-process-0.2.13.0-9HJrZ2dltKn6LhYphnay77
    unicode-transforms-0.4.0.1-58PMlC1oO3AKRtahiZEOtu unix-2.8.4.0
    unix-compat-0.7.4.1-Ihfe6doCANm1TVMx2D80dC
    unliftio-0.2.25.1-HBz9luDISr2DkipcdISm26
    unordered-containers-0.2.21-A5j6YbVJ6iQ4Gx0hziy0Dr
    vector-0.13.2.0-HIEoUaJKlQrG3qeQBTxJjw
    yaml-0.11.11.2-9piUJVvEUYuG0CUDTmcMvP
    zip-archive-0.4.3.2-9uTxSUznKixFfAkalbVnMD
    zlib-0.7.1.0-5H6r3qMV1iE2lgCYaQ5cZ

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

